pub struct GridIndexCell {
pub lng: i32,
pub lat: i32,
pub tz_indices: Vec<u32>,
}Expand description
GridIndexCell records the timezone indices that intersect a single 1°×1° cell. tz_indices are 0-based positions into the timezones array of the companion CompressedTopoTimezones (or Timezones) file, matching the order used by Finder.items.
Fields
lng: i32floor(longitude), -180..179
lat: i32floor(latitude), -90..89
tz_indices: Vec<u32>Trait Implementations
Sourceimpl Clone for GridIndexCell
impl Clone for GridIndexCell
Sourcefn clone(&self) -> GridIndexCell
fn clone(&self) -> GridIndexCell
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GridIndexCell
impl Debug for GridIndexCell
Sourceimpl Default for GridIndexCell
impl Default for GridIndexCell
Sourceimpl Hash for GridIndexCell
impl Hash for GridIndexCell
Sourceimpl Message for GridIndexCell
impl Message for GridIndexCell
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GridIndexCell
impl PartialEq for GridIndexCell
Sourcefn eq(&self, other: &GridIndexCell) -> bool
fn eq(&self, other: &GridIndexCell) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for GridIndexCell
impl StructuralPartialEq for GridIndexCell