pub struct TopoTimezones {
pub shared_edges: Vec<SharedEdge>,
pub timezones: Vec<TopoTimezone>,
pub version: String,
}Expand description
Timezones in topology format with shared-edge deduplication. Shared timezone boundaries are stored exactly once in shared_edges; rings reference them by ID rather than duplicating the point sequences. This format targets full-precision data where ~52% of boundary edges are shared, reducing the 96 MB full dataset by ~30–35 MB.
Fields
timezones: Vec<TopoTimezone>version: StringTrait Implementations
Sourceimpl Clone for TopoTimezones
impl Clone for TopoTimezones
Sourcefn clone(&self) -> TopoTimezones
fn clone(&self) -> TopoTimezones
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TopoTimezones
impl Debug for TopoTimezones
Sourceimpl Default for TopoTimezones
impl Default for TopoTimezones
Sourceimpl Message for TopoTimezones
impl Message for TopoTimezones
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for TopoTimezones
impl PartialEq for TopoTimezones
Sourcefn eq(&self, other: &TopoTimezones) -> bool
fn eq(&self, other: &TopoTimezones) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TopoTimezones